@@ -10,6 +10,8 @@
 #include <QStandardPaths>
 #include <QUrl>
 
+#include <KLocalizedString>
+
 #ifdef Q_OS_ANDROID
 #include <MauiKit/Core/mauiandroid.h>
 #endif
@@ -79,7 +81,10 @@ public:
         "text/x-python",
         "text/*",
         "text/x-copying",
+        "text/x-dbus-service",
+        "text/x-gettext-translation",
         "application/xml",
+        "application/vnd.kde.knotificationrc",
         "application/x-gitignore",
         "application/javascript",
         "application/json",
@@ -111,7 +116,10 @@ public:
             "application/pdf", 
             "application/rtf",
             "application/doc",
-            "application/odf"};
+            "application/odf",
+            "application/vnd.comicbook+zip",         
+            "application/vnd.comicbook+rar"            
+        };
         
         inline static const QStringList COMPRESSED_MIMETYPES = {
             "application/x-compress", 
@@ -266,21 +274,24 @@ public:
                                                                                                                                                                                 {PATHTYPE_KEY::FISH_PATH, PATHTYPE_SCHEME[PATHTYPE_KEY::FISH_PATH] + "://"},
                                                                                                                                                                                 {PATHTYPE_KEY::MTP_PATH, PATHTYPE_SCHEME[PATHTYPE_KEY::MTP_PATH] + "://"}};
                                                                                                                                                                                 
-                                                                                                                                                                                inline static const QHash<PATHTYPE_KEY, QString> PATHTYPE_LABEL = {{PATHTYPE_KEY::PLACES_PATH, ("Places")},
-                                                                                                                                                                                {PATHTYPE_KEY::BOOKMARKS_PATH, ("Bookmarks")},
-                                                                                                                                                                                {PATHTYPE_KEY::DRIVES_PATH, ("Drives")},
-                                                                                                                                                                                {PATHTYPE_KEY::APPS_PATH, ("Apps")},
-                                                                                                                                                                                {PATHTYPE_KEY::REMOTE_PATH, ("Remote")},
-                                                                                                                                                                                {PATHTYPE_KEY::REMOVABLE_PATH, ("Removable")},
-                                                                                                                                                                                {PATHTYPE_KEY::UNKNOWN_TYPE, ("Unknown")},
-                                                                                                                                                                                {PATHTYPE_KEY::TRASH_PATH, ("Trash")},
-                                                                                                                                                                                {PATHTYPE_KEY::TAGS_PATH, ("Tags")},
-                                                                                                                                                                                {PATHTYPE_KEY::SEARCH_PATH, ("Search")},
-                                                                                                                                                                                {PATHTYPE_KEY::CLOUD_PATH, ("Cloud")},
-                                                                                                                                                                                {PATHTYPE_KEY::FISH_PATH, ("Remote")},
-                                                                                                                                                                                {PATHTYPE_KEY::MTP_PATH, ("Drives")},
-                                                                                                                                                                                {PATHTYPE_KEY::OTHER_PATH, ("Others")},
-                                                                                                                                                                                {PATHTYPE_KEY::QUICK_PATH, ("Quick")}};
+                                
+/**
+ *This is a user visible and translatable string, so it should not be used as a key anywhere
+ **/                                                                                                                                                                                inline static const QHash<PATHTYPE_KEY, QString> PATHTYPE_LABEL = {{PATHTYPE_KEY::PLACES_PATH, ("Places")},
+                                                                                                                                                                                {PATHTYPE_KEY::BOOKMARKS_PATH, i18nd("mauikitfilebrowsing","Bookmarks")},
+                                                                                                                                                                                {PATHTYPE_KEY::DRIVES_PATH, i18nd("mauikitfilebrowsing","Drives")},
+                                                                                                                                                                                {PATHTYPE_KEY::APPS_PATH, i18nd("mauikitfilebrowsing","Apps")},
+                                                                                                                                                                                {PATHTYPE_KEY::REMOTE_PATH, i18nd("mauikitfilebrowsing","Remote")},
+                                                                                                                                                                                {PATHTYPE_KEY::REMOVABLE_PATH, i18nd("mauikitfilebrowsing","Removable")},
+                                                                                                                                                                                {PATHTYPE_KEY::UNKNOWN_TYPE, i18nd("mauikitfilebrowsing","Unknown")},
+                                                                                                                                                                                {PATHTYPE_KEY::TRASH_PATH, i18nd("mauikitfilebrowsing","Trash")},
+                                                                                                                                                                                {PATHTYPE_KEY::TAGS_PATH, i18nd("mauikitfilebrowsing","Tags")},
+                                                                                                                                                                                {PATHTYPE_KEY::SEARCH_PATH, i18nd("mauikitfilebrowsing","Search")},
+                                                                                                                                                                                {PATHTYPE_KEY::CLOUD_PATH, i18nd("mauikitfilebrowsing","Cloud")},
+                                                                                                                                                                                {PATHTYPE_KEY::FISH_PATH, i18nd("mauikitfilebrowsing","Remote")},
+                                                                                                                                                                                {PATHTYPE_KEY::MTP_PATH, i18nd("mauikitfilebrowsing","Drives")},
+                                                                                                                                                                                {PATHTYPE_KEY::OTHER_PATH, i18nd("mauikitfilebrowsing","Others")},
+                                                                                                                                                                                {PATHTYPE_KEY::QUICK_PATH, i18nd("mauikitfilebrowsing","Quick")}};
                                                                                                                                                                                 
                                                                                                                                                                                 /**
                                                                                                                                                                                  * @brief DataPath
